==> cxf-testutils-3.2.13-sources.jar: org/apache/cxf/greeter_control/FaultThrowingInterceptor.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.greeter_control;

import java.text.MessageFormat;
import java.util.logging.Logger;

import org.apache.cxf.common.logging.LogUtils;
import org.apache.cxf.interceptor.Fault;
import org.apache.cxf.message.Message;
import org.apache.cxf.message.MessageUtils;
import org.apache.cxf.phase.AbstractPhaseInterceptor;
import org.apache.cxf.phase.Phase;

/**
 *
 */
public class FaultThrowingInterceptor extends AbstractPhaseInterceptor<Message> {

    public static final MessageFormat MESSAGE_FORMAT
        = new MessageFormat("Interceptor fault in phase {0}.");
    private static final Logger LOG = LogUtils.getLogger(FaultThrowingInterceptor.class);

    public FaultThrowingInterceptor() {
        super(Phase.USER_LOGICAL);
    }


    public FaultThrowingInterceptor(String phase) {
        super(phase);
    }

    public synchronized void handleMessage(Message message) throws Fault {
        if (MessageUtils.isRequestor(message)) {
            return;
        }
        String msg = MESSAGE_FORMAT.format(new Object[] {getPhase()});
        LOG.fine(msg);
        throw new Fault(new RuntimeException(msg));
    }
}

==> cxf-testutils-3.4.9-sources.jar: org/apache/cxf/greeter_control/FaultThrowingInterceptor.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.greeter_control;

import java.text.MessageFormat;
import java.util.logging.Logger;

import org.apache.cxf.common.logging.LogUtils;
import org.apache.cxf.interceptor.Fault;
import org.apache.cxf.message.Message;
import org.apache.cxf.message.MessageUtils;
import org.apache.cxf.phase.AbstractPhaseInterceptor;
import org.apache.cxf.phase.Phase;

/**
 *
 */
public class FaultThrowingInterceptor extends AbstractPhaseInterceptor<Message> {

    public static final MessageFormat MESSAGE_FORMAT
        = new MessageFormat("Interceptor fault in phase {0}.");
    private static final Logger LOG = LogUtils.getLogger(FaultThrowingInterceptor.class);

    public FaultThrowingInterceptor() {
        super(Phase.USER_LOGICAL);
    }


    public FaultThrowingInterceptor(String phase) {
        super(phase);
    }

    public void handleMessage(Message message) throws Fault {
        if (MessageUtils.isRequestor(message)) {
            return;
        }
        String msg = null;
        synchronized (MESSAGE_FORMAT) {
            msg = MESSAGE_FORMAT.format(new Object[] {getPhase()});
        }
        LOG.fine(msg);
        throw new Fault(new RuntimeException(msg));
    }
}
